import os
import logging

LOGLEVEL = os.environ.get("LOGLEVEL", "DEBUG")
_log_format = f"%(asctime)s - [%(levelname)s] - %(name)s - (%(filename)s).%(funcName)s -- %(pathname)s:(%(lineno)d) - %(message)s"  # noqa: F541 E501


def get_stream_handler(log_format=_log_format):
    stream_handler = logging.StreamHandler()
    stream_handler.setLevel(LOGLEVEL)
    stream_handler.setFormatter(logging.Formatter(log_format))
    return stream_handler


def get_logger(name, log_format=_log_format):
    logger = logging.getLogger(name)
    logger.setLevel(LOGLEVEL)
    logger.addHandler(get_stream_handler(log_format))
    return logger


def log(class_name):
    return get_logger(class_name)



# flake8: noqa
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blockchain_txn_add_gateway_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='blockchain_txn_add_gateway_v1.proto',
  package='helium',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#blockchain_txn_add_gateway_v1.proto\x12\x06helium\"\xbd\x01\n\x1d\x62lockchain_txn_add_gateway_v1\x12\r\n\x05owner\x18\x01 \x01(\x0c\x12\x0f\n\x07gateway\x18\x02 \x01(\x0c\x12\x17\n\x0fowner_signature\x18\x03 \x01(\x0c\x12\x19\n\x11gateway_signature\x18\x04 \x01(\x0c\x12\r\n\x05payer\x18\x05 \x01(\x0c\x12\x17\n\x0fpayer_signature\x18\x06 \x01(\x0c\x12\x13\n\x0bstaking_fee\x18\x07 \x01(\x04\x12\x0b\n\x03\x66\x65\x65\x18\x08 \x01(\x04\x62\x06proto3'
)




_BLOCKCHAIN_TXN_ADD_GATEWAY_V1 = _descriptor.Descriptor(
  name='blockchain_txn_add_gateway_v1',
  full_name='helium.blockchain_txn_add_gateway_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner', full_name='helium.blockchain_txn_add_gateway_v1.owner', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gateway', full_name='helium.blockchain_txn_add_gateway_v1.gateway', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_signature', full_name='helium.blockchain_txn_add_gateway_v1.owner_signature', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gateway_signature', full_name='helium.blockchain_txn_add_gateway_v1.gateway_signature', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payer', full_name='helium.blockchain_txn_add_gateway_v1.payer', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payer_signature', full_name='helium.blockchain_txn_add_gateway_v1.payer_signature', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='staking_fee', full_name='helium.blockchain_txn_add_gateway_v1.staking_fee', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee', full_name='helium.blockchain_txn_add_gateway_v1.fee', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=237,
)

DESCRIPTOR.message_types_by_name['blockchain_txn_add_gateway_v1'] = _BLOCKCHAIN_TXN_ADD_GATEWAY_V1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

blockchain_txn_add_gateway_v1 = _reflection.GeneratedProtocolMessageType('blockchain_txn_add_gateway_v1', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKCHAIN_TXN_ADD_GATEWAY_V1,
  '__module__' : 'blockchain_txn_add_gateway_v1_pb2'
  # @@protoc_insertion_point(class_scope:helium.blockchain_txn_add_gateway_v1)
  })
_sym_db.RegisterMessage(blockchain_txn_add_gateway_v1)


# @@protoc_insertion_point(module_scope)
